/*	$Id: pt1reg.h,v 1.1 2014/08/07 08:44:11 tsubai Exp $	*/

/*-
 * Copyright (c) 2013,2014 Tsubai Masanari.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* PCI register offset */
#define PT_COMMAND_REG	0x00
#define PT_STATUS_REG	0x00
#define PT_TUNER_REG	0x04	/* Tuner control */
#define PT_TEST_EN_REG	0x08	/* (W) Stream enable (cf. SetTestMode()) */
#define PT_I2CREAD_REG	0x08	/* (R) I2C read value */
#define PT_TS_GRAY_REG	0x0c
#define PT_CODE_REG	0x10	/* (W) I2C RAM */
#define PT_ERROR_S1	0x10	/* (R) Error packets */
#define PT_DMA_REG	0x14	/* (W) DMA descriptor address */
#define PT_ERROR_T1	0x14
#define PT_ERROR_S2	0x18
#define PT_ERROR_T2	0x1c

/* STATUS */
#define PCI_LOCKED	0x00000001
#define RAM_LOCKED	0x00000002
#define RAM_SHIFT_DONE	0x00000004
#define RAM_OVERFLOW	0x00000008	/* FIFO full */
#define DMA_ERROR	0x00000010	/* TransferCounter0 */
#define DMA_WARN	0x00000020	/* TransferCounter1 */
#define DMA_BUSY	0x00000040
#define I2C_BUSY	0x00000080
#define ID_SYNC		0x20000000
#define ID_DATA		0x40000000
#define UNLOCKED	0x80000000

/* COMMAND */
#define RAM_SHIFT_INC	0x00000001	/* RAM shift direction */
#define RAM_SHIFT_DEC	0x00000000
#define RAM_ENABLE	0x00000002
#define I2C_EXEC	0x00000004	/* Start I2C transfer */
#define ID_PULSE	0x00000008
#define RESET_DMACTR	0x00000010	/* Reset DMA xfer counter */
#define INC_DMACTR	0x00000020	/* Increment xfer counter */
#define START_DMA	0x00000040	/* Start DMA */
#define PCI_RESET	0x00010000
#define RAM_RESET	0x00020000
#define FAST_BTB_EN	0x00040000	/* Enable fast back-to-back */
#define STOP_DMA	0x00080000	/* Stop DMA */
/* #define PCI_RESET_MASK	(PCI_RESET << 8) */
/* #define RAM_RESET_MASK	(RAM_RESET << 8) */
/* #define FAST_BTB_EN_MASK	(FAST_BTB_EN << 8) */
/* #define STOP_DMA_MASK	(STOP_DMA << 8) */

#define ON(x)	((x) << 8 | (x))
#define OFF(x)	((x) << 8)

/* PT_TUNER_REG - LNB power, tuner reset, et al. */
#define PT_TUNER_POWER    0x0001
#define PT_LNB_0V         0x0000
#define PT_LNB_11V        0x0004
#define PT_LNB_15V        0x0006
#define PT_TUNER_RESET    0x0008
#define PT_TUNER_POWER_S1 0x0010
#define PT_TUNER_POWER_S2 0x0020
#define PT_TUNER_POWER_T1 0x00c0
#define PT_TUNER_POWER_T2 0x0140

/* PT_TEST_EN_REG */
#define PT_STREAM0_EN 0x00000001
#define PT_STREAM1_EN 0x00000002
#define PT_STREAM2_EN 0x00000004
#define PT_STREAM3_EN 0x00000008
#define PT_TEST_MODE  0x00010000

/* DMA descriptor */
struct pt_dmadesc {
	u_int32_t next;		/* next descriptor PA >> 12 */
	u_int32_t pa[511];	/* buffer PA >> 12 */
	u_char pad[2048];
};

/*
 * micropacket format
 * 31 - 24: data byte 2
 * 23 - 16: data byte 1
 * 15 -  8: data byte 0
 *  7 -  5: channel number (1 - 4)
 *  4 -  2: counter
 *       1: start of packet
 *       0: error
 */
#if _BYTE_ORDER == _BIG_ENDIAN
#define MICROPACKET_ERROR	0x00000001
#define MICROPACKET_START	0x00000002	/* Start of TS packet */
#define MICROPACKET_COUNTER(m)	(((m) & 0x0000001c) >> 2)
#define MICROPACKET_CHANNEL(m)	(((m) & 0x000000e0) >> 5) /* Channel (1-4) */
#define MICROPACKET_BYTE0(m)	(((m) & 0x0000ff00) >> 8)
#define MICROPACKET_BYTE1(m)	(((m) & 0x00ff0000) >> 16)
#define MICROPACKET_BYTE2(m)	(((m) & 0xff000000) >> 24)
#else
#define MICROPACKET_ERROR	0x01000000
#define MICROPACKET_START	0x02000000
#define MICROPACKET_COUNTER(m)	(((m) & 0x1c000000) >> 26)
#define MICROPACKET_CHANNEL(m)	(((m) & 0xe0000000) >> 29)
#define MICROPACKET_BYTE0(m)	(((m) & 0x00ff0000) >> 16)
#define MICROPACKET_BYTE1(m)	(((m) & 0x0000ff00) >> 8)
#define MICROPACKET_BYTE2(m)	(((m) & 0x000000ff))
#endif

/* PCI product IDs */
#define PCI_PRODUCT_PT1 0x211a
#define PCI_PRODUCT_PT2 0x222a

/* I2C addresses */
#define TUNER_ADDR_S1 0x36
#define TUNER_ADDR_T1 0x34
#define TUNER_ADDR_S2 0x32
#define TUNER_ADDR_T2 0x30

/* PT's page size */
#define PT_PGSZ 4096

/* TS packet length */
#define TSPKTLEN 188

#define NTUNER 4
