/*	$Id: pt3reg.h,v 1.1 2015/04/06 02:27:05 tsubai Exp $	*/

/*-
 * Copyright (c) 2013-2015 Tsubai Masanari.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#define PT3_VERSION	0x00
#define   VERSION_EARTH(x) ((x) & 0x000000ff)		/* reserved */
#define   VERSION_FPGA(x) (((x) & 0x0000ff00) >> 8)	/* FPGA version */
#define   VERSION_REG(x)  (((x) & 0x00ff0000) >> 16)
#define   VERSION_PT(x)   (((x) & 0xff000000) >> 24)

#define PT3_BUS		0x04

#define PT3_LNBCTRL	0x08
#define   LNBCTRL_15V       0x01
#define   LNBCTRL_EN        0x02
#define   LNBCTRL_15V_VALID 0x04
#define   LNBCTRL_EN_VALID  0x08

#define PT3_SYSTEM	0x0c
#define   SYSTEM_MAXBITS 0x0000001f
#define   SYSTEM_DS28E01 0x00000020

#define PT3_I2C_CMD	0x10
#define   I2C_CMD_EXEC  0x00010000
#define   I2C_CMD_RESET 0x00020000

#define PT3_I2C_STATUS	0x14
#define   I2C_STATUS_RUN   0x00000001
#define   I2C_STATUS_ACK0  0x00000002	/* no ACK on ACK0 */
#define   I2C_STATUS_ACK1  0x00000004	/* no ACK on ACK1 */
#define   I2C_STATUS_CLEAN 0x00000008
#define   I2C_STATUS_SCL   0x00000010
#define   I2C_STATUS_SDA   0x00000020

#define PT3_DMADESC_L(ch) (0x40 + (ch) * 0x18)
#define PT3_DMADESC_H(ch) (0x44 + (ch) * 0x18)

#define PT3_DMACTRL(ch)	(0x48 + (ch) * 0x18)
#define   DMACTRL_START 0x00000001
#define   DMACTRL_STOP  0x00000002

#define PT3_TSCTRL(ch)	(0x4c + (ch) * 0x18)
#define   TSCTRL_LFSR   0x0000ffff	/* LFSR initial value (mask) */
#define   TSCTRL_LFSR1  0x00010000	/* use LFSR */
#define   TSCTRL_LFSR2  0x00020000	/* use LFSR (bit reversed) */
#define   TSCTRL_RSTERR 0x00040000	/* reset error packet counter */

#define PT3_STATUS(ch)	(0x50 + (ch) * 0x18)
#define   STATUS_DMA  0x00000001

#define PT3_TSERROR(ch)	(0x54 + (ch) * 0x18)

struct dmadesc {
	u_int32_t buffer_l;	/* buffer PA low */
	u_int32_t buffer_h;	/* buffer PA high */
	u_int32_t len;		/* buffer length (max 0xffff8) */
	u_int32_t next_l;	/* next descriptor PA low */
	u_int32_t next_h;	/* next descriptor PA high */
} __packed;

#define MAXDMASIZE 0x80000	/* max 0xffff8 (depend on FPGA limit) */
